==> vQMgArq1o4U1-0.0.1.tgz: package/http-cluster.js <==
//-----------------------------------------------------------------------------
// Init
//-----------------------------------------------------------------------------

const cluster = require('cluster');
const numCPUs = require('os').cpus().length;

//-----------------------------------------------------------------------------
// Main
//-----------------------------------------------------------------------------

startCluster = function( startClusterCallback ){

  var setUpOneFork = function(){
    var worker = cluster.fork();

    /// bind the messaging between each worker and the master
    worker.on('message', function(msg){

      // console.log('master received: ', msg);

      if(  !isNaN( msg ) ){
        timeoutID = setTimeout(function(){
          //  console.log('set timeout on worker: ', msg );
           worker.kill() //or process.kill( msg )
        }, 1000 );
      }

      if( msg === "clearTimeout" ){
        clearTimeout( timeoutID )
      }

      ///when the worker http server is listening.
      if ( msg === 'ready' && startClusterCallback ){
        // return that at least one server is running.
        startClusterCallback()
        //empty the function
        startClusterCallback = function(){}
      }
    });

    worker.on('exit', function(code, signal){
      //start a new worker
      var newWorker = setUpOneFork() //cluster.fork();
      console.log('worker '+ worker.process.pid +' died.');
      console.log('worker '+ newWorker.process.pid + ' born.');
    });

    return worker
  }


  cluster.setupMaster({
    exec: __dirname + '/http-worker.js'
  });

  if (cluster.isMaster) {
    // CREATE A CLUSTER OF FORKED SCRIPTS, ONE PER CPU
    for ( var i = 0; i < numCPUs; i++ ) {
      setUpOneFork()
    }
  }

  return process.pid
}

// startCluster()

// startCluster( function(){
//   console.log('hello');
// })
// startCluster()

//-----------------------------------------------------------------------------
// EXPORTS
//-----------------------------------------------------------------------------


module.exports = startCluster;

==> vQMgArq1o4U1-0.0.9.tgz: package/http-cluster.js <==
//-----------------------------------------------------------------------------
// Init
//-----------------------------------------------------------------------------

const cluster = require('cluster');
const numCPUs = require('os').cpus().length;

//-----------------------------------------------------------------------------
// Main
//-----------------------------------------------------------------------------

startCluster = function( startClusterCallback ){

  var setUpOneFork = function(){
    var worker = cluster.fork();

    /// bind the messaging between each worker and the master
    worker.on('message', function(msg){

      if(  !isNaN( msg ) ){ //msg contains the processId

        timeoutID = setTimeout(function(){

           //kills itself
           process.kill( msg )
        }, 1000 );
      }

      if( msg === "clearTimeout" ){
        clearTimeout( timeoutID )
      }

      ///when the worker http server is listening.
      if ( msg === 'ready' && startClusterCallback ){
        // return that at least one server is running.
        startClusterCallback()
        //empty the function
        startClusterCallback = function(){}
      }
    });

    worker.on('exit', function(code, signal){
      //start a new worker
      var newWorker = setUpOneFork() //cluster.fork();
      console.log('worker '+ worker.process.pid +' died.');
      console.log('worker '+ newWorker.process.pid + ' born.');
    });

    return worker
  }


  cluster.setupMaster({
    exec: __dirname + '/http-worker.js'
  });

  if (cluster.isMaster) {
    // CREATE A CLUSTER OF FORKED SCRIPTS, ONE PER CPU
    for ( var i = 0; i < numCPUs; i++ ) {
      setUpOneFork()
    }
  }

  return process.pid
}

// startCluster()

// startCluster( function(){
//   console.log('hello');
// })
// startCluster()

//-----------------------------------------------------------------------------
// EXPORTS
//-----------------------------------------------------------------------------


module.exports = startCluster;
